Struct diem_network_address_encryption::Encryptor [−][src]
pub struct Encryptor<S> { /* fields omitted */ }Implementations
This generates an empty encryptor for use in scenarios where encryption is not necessary. Any encryption operations (e.g., encrypt / decrypt) will return errors.
This generates an encryptor for use in testing scenarios. The encryptor is initialized with a test network encryption key.